==> metaArray_1.22.0.zip: metaArray/doc/metaArray.R <==
###################################################
### chunk number 1: 
###################################################
library(metaArray)
library(Biobase)
library(MergeMaid)
data(mdata)
common <- intersect(rownames(chen.poe),rownames(garber.poe)) 
common <- intersect(common, rownames(lapointe.poe))
chen.poe <- chen.poe[match(common, rownames(chen.poe)),]
garber.poe <- garber.poe[match(common, rownames(garber.poe)),]
lapointe.poe <- lapointe.poe[match(common, rownames(lapointe.poe)),]
vars <- list("var1","var2")
names(vars) <- names(chen.spl)
pdata1 <- new("AnnotatedDataFrame")
pData(pdata1) <- chen.spl
varLabels(pdata1) <- vars
sample1 <- new("ExpressionSet", exprs=chen.poe, phenoData = pdata1)
names(vars) <- names(garber.spl)
pdata2 <- new("AnnotatedDataFrame")
pData(pdata2) <- garber.spl
varLabels(pdata2) <- vars
sample2 <- new("ExpressionSet", exprs=garber.poe, phenoData = pdata2)
names(vars) <- names(lapointe.spl)
pdata3 <- new("AnnotatedDataFrame")
pData(pdata3) <- lapointe.spl
varLabels(pdata3) <- vars
sample3 <- new("ExpressionSet", exprs=lapointe.poe, phenoData = pdata3)
merged <- mergeExprs(sample1,sample2,sample3)


###################################################
### chunk number 2:  eval=FALSE
###################################################
## merged.cor <- intcor(merged)$avg.cor
## mData <- exprs(intersection(merged)); mCl <- NULL
## mData <- mData[merged.cor > median(merged.cor),]
## for(i in 1:length(merged)) {
##   mCl <- c(mCl, pData(merged[i])$metastasis)
## }


###################################################
### chunk number 3: 
###################################################
em.draw(as.numeric(chen[1,]), cl=ncol(chen))


###################################################
### chunk number 4:  eval=FALSE
###################################################
## z.stat <- Zscore(merged)

==> metaArray_1.26.0.zip: metaArray/doc/metaArray.R <==
###################################################
### chunk number 1: 
###################################################
#line 45 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpUFRIZE/R.INSTALL1f3030da/metaArray/inst/doc/metaArray.Rnw"
library(metaArray)
library(Biobase)
library(MergeMaid)
data(mdata)
common <- intersect(rownames(chen.poe),rownames(garber.poe)) 
common <- intersect(common, rownames(lapointe.poe))
chen.poe <- chen.poe[match(common, rownames(chen.poe)),]
garber.poe <- garber.poe[match(common, rownames(garber.poe)),]
lapointe.poe <- lapointe.poe[match(common, rownames(lapointe.poe)),]
vars <- list("var1","var2")
names(vars) <- names(chen.spl)
pdata1 <- new("AnnotatedDataFrame")
pData(pdata1) <- chen.spl
varLabels(pdata1) <- vars
sample1 <- new("ExpressionSet", exprs=chen.poe, phenoData = pdata1)
names(vars) <- names(garber.spl)
pdata2 <- new("AnnotatedDataFrame")
pData(pdata2) <- garber.spl
varLabels(pdata2) <- vars
sample2 <- new("ExpressionSet", exprs=garber.poe, phenoData = pdata2)
names(vars) <- names(lapointe.spl)
pdata3 <- new("AnnotatedDataFrame")
pData(pdata3) <- lapointe.spl
varLabels(pdata3) <- vars
sample3 <- new("ExpressionSet", exprs=lapointe.poe, phenoData = pdata3)
merged <- mergeExprs(sample1,sample2,sample3)


###################################################
### chunk number 2:  eval=FALSE
###################################################
## #line 83 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpUFRIZE/R.INSTALL1f3030da/metaArray/inst/doc/metaArray.Rnw"
## merged.cor <- intcor(merged)$avg.cor
## mData <- exprs(intersection(merged)); mCl <- NULL
## mData <- mData[merged.cor > median(merged.cor),]
## for(i in 1:length(merged)) {
##   mCl <- c(mCl, pData(merged[i])$metastasis)
## }


###################################################
### chunk number 3: 
###################################################
#line 104 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpUFRIZE/R.INSTALL1f3030da/metaArray/inst/doc/metaArray.Rnw"
em.draw(as.numeric(chen[1,]), cl=ncol(chen))


###################################################
### chunk number 4:  eval=FALSE
###################################################
## #line 112 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpUFRIZE/R.INSTALL1f3030da/metaArray/inst/doc/metaArray.Rnw"
## z.stat <- Zscore(merged)
